----------------------------------------------------------------------------------
-- Company: 
-- Engineer: 
-- 
-- Create Date:    13:51:28 08/13/2014 
-- Design Name: 
-- Module Name:    NBitAdderTop - Behavioral 
-- Project Name: 
-- Target Devices: 
-- Tool versions: 
-- Description: 
--
-- Dependencies: 
--
-- Revision: 
-- Revision 0.01 - File Created
-- Additional Comments: 
--
----------------------------------------------------------------------------------
library IEEE;
use IEEE.STD_LOGIC_1164.ALL;

entity NBitAdderTop is
   Port( 
		sw  : in   STD_LOGIC_VECTOR (7 downto 0);
      clk : in   STD_LOGIC;
      seg : out  STD_LOGIC_VECTOR (6 downto 0);
      an  : out  STD_LOGIC_VECTOR (3 downto 0);
      dp  : out  STD_LOGIC
	);
end NBitAdderTop;

architecture Behavioral of NBitAdderTop is

	component NBitAdder is
		generic(N : positive := 4);
		Port( 
			a : in   STD_LOGIC_VECTOR (N-1 downto 0);
			b : in   STD_LOGIC_VECTOR (N-1 downto 0);
			y : out  STD_LOGIC_VECTOR (N-1 downto 0)
		);
	end component;

	component CLKCounter
		Port 
		( 
			clk_in   : in   STD_LOGIC;
			clk_out  : out  STD_LOGIC
		);
	end component;

	component PositionValueCounter
		Port 
		( 
			x       : in   STD_LOGIC_VECTOR (3 downto 0);
			clk_out : in   STD_LOGIC;
			y0      : out  STD_LOGIC_VECTOR (3 downto 0);
			y1      : out  STD_LOGIC
		);
	end component;

	component Position0Display
		Port 
		( 
			y0   : in   STD_LOGIC_VECTOR (3 downto 0);
			seg0 : out  STD_LOGIC_VECTOR (6 downto 0)
		);
	end component;

	component Position1Display
		Port 
		( 
			y1   : in   STD_LOGIC;
			seg1 : out  STD_LOGIC_VECTOR (6 downto 0)
		);
	end component;

	component DisplayController
		Port 
		( 
			seg0    : in   STD_LOGIC_VECTOR (6 downto 0);
			seg1    : in   STD_LOGIC_VECTOR (6 downto 0);
			clk_out : in   STD_LOGIC;
			seg     : out  STD_LOGIC_VECTOR (6 downto 0);
			an      : out  STD_LOGIC_VECTOR (3 downto 0);
			dp      : out  STD_LOGIC
		);
	end component;
	
	signal clk_out_signal : STD_LOGIC;
	signal x_signal       : STD_LOGIC_VECTOR(3 downto 0);
	signal y0_signal      : STD_LOGIC_VECTOR(3 downto 0);
	signal y1_signal      : STD_LOGIC;
	signal seg0_signal    : STD_LOGIC_VECTOR(6 downto 0);
	signal seg1_signal    : STD_LOGIC_VECTOR(6 downto 0);
	
begin

	N_BIT_ADD : NBitAdder
	generic map(
		N => 4
	)
	port map(
		a => sw(3 downto 0),
		b => sw(7 downto 4),
		y => x_signal
	);
	
	CLK_CNT : CLKCounter
	port map(
		clk_in  => clk,
		clk_out => clk_out_signal
	);

	POS_VAL_CNT : PositionValueCounter
	port map(
		x       => x_signal,
		clk_out => clk_out_signal,
		y0      => y0_signal,
		y1      => y1_signal
	);
	
	POS_0_DISP : Position0Display
	port map(
		y0   => y0_signal,
		seg0 => seg0_signal
	);
	
	POS_1_DISP : Position1Display
	port map(
		y1   => y1_signal,
		seg1 => seg1_signal
	);
	
	DISP_CNTRL : DisplayController
	port map(
		seg0    => seg0_signal,
		seg1    => seg1_signal,
		clk_out => clk_out_signal,
		seg     => seg,
		an      => an,
		dp      => dp
	);

end Behavioral;

